<?php

namespace Superrobota\Phoneproviders\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Phoneproviders\Models\Phoneproviders;

class PhoneprovidersPolicy
{

    /**
     * Determine if the given user can view the phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function view(UserPolicy $user, Phoneproviders $phoneproviders)
    {
        if ($user->canDo('phoneproviders.phoneproviders.view') && $user->isAdmin()) {
            return true;
        }

        return $phoneproviders->user_id == user_id() && $phoneproviders->user_type == user_type();
    }

    /**
     * Determine if the given user can create a phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('phoneproviders.phoneproviders.create');
    }

    /**
     * Determine if the given user can update the given phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function update(UserPolicy $user, Phoneproviders $phoneproviders)
    {
        if ($user->canDo('phoneproviders.phoneproviders.edit') && $user->isAdmin()) {
            return true;
        }

        return $phoneproviders->user_id == user_id() && $phoneproviders->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Phoneproviders $phoneproviders)
    {
        return $phoneproviders->user_id == user_id() && $phoneproviders->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Phoneproviders $phoneproviders)
    {
        if ($user->canDo('phoneproviders.phoneproviders.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given phoneproviders.
     *
     * @param UserPolicy $user
     * @param Phoneproviders $phoneproviders
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Phoneproviders $phoneproviders)
    {
        if ($user->canDo('phoneproviders.phoneproviders.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
